@@ -17,7 +17,7 @@
  * GNU Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+ * License along with this library.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef LIBKGAPI2_MODIFYJOB_H
@@ -29,7 +29,7 @@
 namespace KGAPI2 {
 
 /**
- * @headerfile FetchJob
+ * @headerfile modifyjob.h
  * @brief Abstract superclass for all jobs that somehow modify resources on Google
  *
  * @author Daniel Vrátil <dvratil@redhat.com>
@@ -50,7 +50,7 @@ class KGAPICORE_EXPORT ModifyJob : public KGAPI2::Job
     /**
      * @brief Constructor for jobs that require authentication
      *
-     * @param account Account to use to authenticate the requests send by this job
+     * @param account Account to use to authenticate the requests sent by this job
      * @param parent
      */
     explicit ModifyJob(const KGAPI2::AccountPtr& account, QObject* parent = nullptr);
@@ -58,12 +58,12 @@ class KGAPICORE_EXPORT ModifyJob : public KGAPI2::Job
     /**
      * Destructor
      */
-    virtual ~ModifyJob();
+    ~ModifyJob() override;
 
     /**
      * @return Returns modified items.
      */
-    ObjectsList items();
+    ObjectsList items() const;
 
   protected:
     /**
@@ -78,7 +78,7 @@ class KGAPICORE_EXPORT ModifyJob : public KGAPI2::Job
      * usually requires reimplementing FetchJob::items as well and storing the
      * parsed items in your implementation.
      *
-     * @param reply A QNetworkReply received from Google server
+     * @param reply A QNetworkReply received from Google's servers
      * @param rawData Content of body of the @p reply. Don't use
      *        QNetworkReply::readAll(), because the content has already been read
      *        by Job implementation and thus it would return empty data.
